@@ -11,12 +11,12 @@ use Bio::Gonzales::Util::Cerial;
 
 use File::Spec;
 
-run_job(
+job->run(
   {
     task => sub {
-      my ( $c, $result_prefix, $idx_item ) = @_;
+      my ( $result_prefix, $idx_item ) = @_;
 
-      INFO "Running $idx_item->[0] -> $result_prefix";
+      job->log->info("Running $idx_item->[0] -> $result_prefix");
       jspew( $result_prefix . ".env.json",  \%ENV );
       jspew( $result_prefix . ".item.json", $idx_item );
       sleep 1;
@@ -24,10 +24,9 @@ run_job(
 
     },
     post_task => sub {
-      my $c = shift;
-      open my $fh, '>', File::Spec->catfile( $c->{result_dir}, 'finished' )
+      open my $fh, '>', File::Spec->catfile( job->config('result_dir'), 'finished' )
         or die "Can't open filehandle: $!";
-      say $fh $c->{job_id};
+      say $fh job->env('job_id');
       $fh->close;
     },
     usage => \&usage,
