@@ -14,12 +14,12 @@ run_job(
             my ( $c, $result_prefix, $in_file ) = @_;
 
             my $filtered_file = "$result_prefix.filt";
-            INFO("in: $in_file filt: $filtered_file");
+            job->log->info("in: $in_file filt: $filtered_file");
 
             my $success = 1;
             #filter sequence for low complexity
-            $success &&= my_sys_non_fatal("$ENV{HOME}/usr/src/psipred/bin/pfilt $in_file >$filtered_file");
-            $success &&= my_sys_non_fatal("$ENV{HOME}/usr/src/psipred/runpsipred $filtered_file");
+            $success &&= job->sys("$ENV{HOME}/usr/src/psipred/bin/pfilt $in_file >$filtered_file");
+            $success &&= job->sys("$ENV{HOME}/usr/src/psipred/runpsipred $filtered_file");
 
             return $success;
         },
